"use strict";
/**
 * FF Typescript Foundation Library
 * Copyright 2021 Ralph Wiedemeier, Frame Factory GmbH
 *
 * License: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
////////////////////////////////////////////////////////////////////////////////
class DragTarget {
    constructor() {
        this.isEnabled = true;
        this.onDragStart = null;
        this.onDragMove = null;
        this.onDragEnd = null;
        this._element = null;
        this._isDragging = false;
        this._startX = 0;
        this._startY = 0;
        this._lastX = 0;
        this._lastY = 0;
        this.onPointerDown = this.onPointerDown.bind(this);
        this.onPointerMove = this.onPointerMove.bind(this);
        this.onPointerUp = this.onPointerUp.bind(this);
    }
    get isDragging() {
        return this._isDragging;
    }
    get startX() {
        return this._startX;
    }
    get startY() {
        return this._startY;
    }
    get lastX() {
        return this._lastX;
    }
    get lastY() {
        return this._lastY;
    }
    bind(element) {
        this.unbind();
        this._element = element;
        element.addEventListener("pointerdown", this.onPointerDown);
        element.addEventListener("pointermove", this.onPointerMove);
        element.addEventListener("pointerup", this.onPointerUp);
        element.addEventListener("pointercancel", this.onPointerUp);
    }
    unbind() {
        const element = this._element;
        this._element = null;
        if (element) {
            element.removeEventListener("pointerdown", this.onPointerDown);
            element.removeEventListener("pointermove", this.onPointerMove);
            element.removeEventListener("pointerup", this.onPointerUp);
            element.removeEventListener("pointercancel", this.onPointerUp);
        }
    }
    onPointerDown(event) {
        if (event.isPrimary && this.isEnabled) {
            this._isDragging = true;
            this._startX = this._lastX = event.clientX;
            this._startY = this._lastY = event.clientY;
            this._element.setPointerCapture(event.pointerId);
            this.onDragStart && this.onDragStart(event);
        }
        event.stopPropagation();
        event.preventDefault();
    }
    onPointerMove(event) {
        if (event.isPrimary && this._isDragging) {
            const dx = event.clientX - this._lastX;
            const dy = event.clientY - this._lastY;
            this.onDragMove && this.onDragMove(event, dx, dy);
            this._lastX = event.clientX;
            this._lastY = event.clientY;
        }
        event.stopPropagation();
        event.preventDefault();
    }
    onPointerUp(event) {
        if (event.isPrimary && this._isDragging) {
            this.onDragEnd && this.onDragEnd(event);
            this._element.releasePointerCapture(event.pointerId);
            this._isDragging = false;
        }
        event.stopPropagation();
        event.preventDefault();
    }
}
exports.default = DragTarget;
//# sourceMappingURL=DragTarget.js.map