"use strict";
/**
 * FF Typescript Foundation Library
 * Copyright 2021 Ralph Wiedemeier, Frame Factory GmbH
 *
 * License: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
const _triggerDownload = function (data, fileName) {
    const dataURL = window.URL.createObjectURL(data);
    const linkElement = document.createElement("a");
    linkElement.download = fileName;
    linkElement.href = dataURL;
    const clickHandler = () => {
        setTimeout(() => {
            URL.revokeObjectURL(dataURL);
            this.removeEventListener("click", clickHandler);
        }, 150);
    };
    linkElement.addEventListener("click", clickHandler);
    document.body.appendChild(linkElement);
    linkElement.click();
    document.body.removeChild(linkElement);
};
exports.default = {
    /**
     * Prompts the user to download the provided text content as a file.
     * @param text text string to include.
     * @param fileName name of the downloadable file.
     */
    text: function (text, fileName) {
        _triggerDownload(new Blob([text], { type: "text/plain" }), fileName);
    },
    /**
     * Prompts the user to download the provided JSON content as a file.
     * @param json JSON data to include.
     * @param fileName name of the downloadable file.
     */
    json: function (json, fileName) {
        if (typeof json === "object") {
            json = JSON.stringify(json);
        }
        _triggerDownload(new Blob([json], { type: "text/json" }), fileName);
    },
};
//# sourceMappingURL=download.js.map