"use strict";
/**
 * FF Typescript Foundation Library
 * Copyright 2021 Ralph Wiedemeier, Frame Factory GmbH
 *
 * License: MIT
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    json: function (url, method, data) {
        return __awaiter(this, void 0, void 0, function* () {
            if (data && typeof data !== "string") {
                data = JSON.stringify(data);
            }
            const params = {
                headers: {
                    "Accept": "application/json",
                    "Content-Type": "application/json",
                },
                method: method,
                credentials: "same-origin",
                body: data
            };
            return fetch(url, params).then(result => {
                if (!result.ok) {
                    const message = `fetch.json (${method} at '${url}'), error: ${result.status} - ${result.statusText}`;
                    console.warn(message);
                    throw new Error(message);
                }
                return result.json();
            }).catch(error => {
                console.warn(`fetch.json (${method} at '${url}'), error: ${error.message}`);
                throw error;
            });
        });
    },
    text: function (url, method, data) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = {
                headers: {
                    "Accept": "text/plain",
                    "Content-Type": "text/plain",
                },
                method: method,
                credentials: "include",
                body: data
            };
            return fetch(url, params).then(result => {
                if (!result.ok) {
                    throw new Error(`status: ${result.status}`);
                }
                return result.text();
            }).catch(error => {
                console.warn(`fetch.text (${method} at '${url}'), error: ${error.message}`);
                throw error;
            });
        });
    },
    file: function (url, method, file, detectType = true) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = {
                method,
                credentials: "include",
                body: file
            };
            if (!detectType) {
                params.headers = {
                    "Content-Type": "application/octet-stream"
                };
            }
            return fetch(url, params).then(result => {
                if (!result.ok) {
                    throw new Error(`status: ${result.status}`);
                }
                return result;
            }).catch(error => {
                console.warn(`fetch.file (${method} at '${url}'), error: ${error.message}`);
                throw error;
            });
        });
    },
    buffer: function (url, method, buffer) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = {
                headers: {
                    "Accept": "application/octet-stream",
                    "Content-Type": "application/octet-stream"
                },
                method,
                credentials: "include",
                body: buffer
            };
            return fetch(url, params).then(result => {
                if (!result.ok) {
                    throw new Error(`status: ${result.status}`);
                }
                return result.arrayBuffer();
            }).catch(error => {
                console.warn(`fetch.buffer (${method} at '${url}'), error: ${error.message}`);
                throw error;
            });
        });
    }
};
//# sourceMappingURL=fetch.js.map