"use strict";
/**
 * FF Typescript Foundation Library
 * Copyright 2021 Ralph Wiedemeier, Frame Factory GmbH
 *
 * License: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalStorage = void 0;
const uniqueId_1 = require("@ff/core/uniqueId");
////////////////////////////////////////////////////////////////////////////////
class LocalStorage {
    constructor() {
        this.storage = window ? window.localStorage : undefined;
    }
    isSupported() {
        return !!this.storage;
    }
    get(endpoint, id) {
        this.throwIfNotSupported();
        const key = this.getKey(endpoint, id);
        const json = this.storage.getItem(key);
        if (!json) {
            return undefined;
        }
        return JSON.parse(json);
    }
    set(endpoint, obj, id) {
        this.throwIfNotSupported();
        id = id || obj["id"] || uniqueId_1.default();
        const key = this.getKey(endpoint, id);
        this.storage.setItem(key, JSON.stringify(obj));
        return id;
    }
    remove(endpoint, id) {
        this.throwIfNotSupported();
        const key = this.getKey(endpoint, id);
        if (this.storage.getItem(key)) {
            this.storage.removeItem(key);
            return true;
        }
        return false;
    }
    getKey(endpoint, id) {
        return endpoint + "/" + id;
    }
    throwIfNotSupported() {
        if (!this.storage) {
            throw new Error("local storage not supported");
        }
    }
}
exports.LocalStorage = LocalStorage;
const localStorage = new LocalStorage();
exports.default = localStorage;
//# sourceMappingURL=localStorage.js.map