"use strict";
/**
 * FF Typescript Foundation Library
 * Copyright 2021 Ralph Wiedemeier, Frame Factory GmbH
 *
 * License: MIT
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalStorageProvider = void 0;
const uniqueId_1 = require("@ff/core/uniqueId");
////////////////////////////////////////////////////////////////////////////////
/**
 * @deprecated
 */
class LocalStorageProvider {
    constructor() {
        this.storage = window ? window.localStorage : undefined;
    }
    get(endpoint, id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.throwIfNotAvailable()
                .then(() => {
                const key = this.getKey(endpoint, id);
                const json = this.storage.getItem(key);
                if (!json) {
                    return null;
                }
                return JSON.parse(json);
            });
        });
    }
    put(endpoint, obj) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.throwIfNotAvailable()
                .then(() => {
                const key = this.getKey(endpoint, obj.id);
                this.storage.setItem(key, JSON.stringify(obj));
            });
        });
    }
    update(endpoint, obj) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.throwIfNotAvailable()
                .then(() => {
                const key = this.getKey(endpoint, obj.id);
                const json = this.storage.getItem(key);
                if (json) {
                    // merge partial update with existing object
                    obj = Object.assign(JSON.parse(json), obj);
                    this.storage.setItem(key, JSON.stringify(obj));
                    return true;
                }
                return false;
            });
        });
    }
    insert(endpoint, obj) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.throwIfNotAvailable()
                .then(() => {
                const id = obj.id || this.createId();
                const key = this.getKey(endpoint, id);
                if (this.storage.getItem(key)) {
                    throw new Error("LocalStorage.insert - item with id exists: " + id);
                }
                this.storage.setItem(key, JSON.stringify(obj));
                return id;
            });
        });
    }
    remove(endpoint, id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.throwIfNotAvailable()
                .then(() => {
                const key = this.getKey(endpoint, id);
                if (this.storage.getItem(key)) {
                    this.storage.removeItem(key);
                    return true;
                }
                return false;
            });
        });
    }
    throwIfNotAvailable() {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                if (this.storage) {
                    resolve();
                }
                else {
                    reject("local storage not available");
                }
            });
        });
    }
    createId() {
        return uniqueId_1.default();
    }
    getKey(endpoint, id) {
        return endpoint + "/" + id;
    }
}
exports.LocalStorageProvider = LocalStorageProvider;
const localStorageProvider = new LocalStorageProvider();
exports.default = localStorageProvider;
//# sourceMappingURL=localStorageProvider.js.map